@@ -36,20 +36,20 @@ class AppDocumentRoot(Component):
         return self._render
 
     def _render(self):
-        if browser and self.__loading:
-            self.__loading = False
-            browser.document.getElementById("webcompy-loading").remove()
         self._property["on_before_rendering"]()
         for child in self._children:
             child._render()
         self._property["on_after_rendering"]()
+        if browser and self.__loading:
+            self.__loading = False
+            browser.document.getElementById("webcompy-loading").remove()
 
     def _init_node(self) -> DOMNode:
         if browser:
             node = browser.document.getElementById("webcompy-app")
-            for name in tuple(node.attrs.keys()):
+            for name in tuple(node.getAttributeNames()):
                 if name != "id":
-                    del node.attrs[name]
+                    node.removeAttribute(name)
             node.__webcompy_node__ = True
             return node
         else:
